
// Copyright 2015 ESRI
//
// All rights reserved under the copyright laws of the United States
// and applicable international laws, treaties, and conventions.
//
// You may freely redistribute and use this sample code, with or
// without modification, provided you include the original copyright
// notice and use restrictions.
//
// See the Sample code usage restrictions document for further information.
//

import QtQuick 2.3
import "helpers.js" as JSHelpers

/////////////////////////////////////////////////////////////////////////////////
// ListView
//
Rectangle {
    id: sideBar
//    anchors {
//        top: titleBar.bottom
//        bottom: parent.bottom
//    }
    color: "lightgray"
    border.color: "black"
    opacity: 0.77
    clip: true
    width: 250 * scaleFactor
    x: 0

    ListView {
        id: listViewItems
        property int itemHeight: Math.min(50 * scaleFactor, 100)
        anchors.fill: parent
        anchors.margins: 5 * scaleFactor

        header: Item {
            height: 30 * scaleFactor
            width: parent.width
            clip: true

            Text {
                text: "Basemaps";
                font {
                    pixelSize: 15 * scaleFactor;
                    bold: true
                }
            }
        }

        model: portalSearchItems.results

        delegate: Item {
            height: listViewItems.itemHeight
            width: parent.width
            clip: true

            Image {
                id: thumbnailImage
                source: thumbnailUrl
                width: Math.min(50 * scaleFactor, 100)
                height: width
            }

            Text {
                anchors {
                    left: thumbnailImage.right;
                    horizontalCenter: parent.horizontalCenter
                    verticalCenter: parent.center
                }

                text: title
                font {
                    pixelSize: 20 * scaleFactor
                    //pixelSize: Math.min(Math.max(listViewItems.width * .04 * scaleFactor, 12 * scaleFactor), 24 * scaleFactor)
                    bold: false
                }
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }

            MouseArea {
                id: itemMouseArea
                anchors.fill: parent
                onClicked: {
                    listViewItems.currentIndex = index
                    var item = listViewItems.model[listViewItems.currentIndex];
                    JSHelpers.selectBaseMap(item.itemId);
                    //selectBaseMap(item.itemId);
                }
            }
        }

        highlightFollowsCurrentItem: true
        highlight: Rectangle {
            height: listViewItems.currentItem.height
            color: "lightsteelblue"
        }
        focus: true

        onModelChanged: {
            if (count > 0) {
                var item = listViewItems.model[0];
                JSHelpers.selectBaseMap(item.itemId);
                //selectBaseMap(item.itemId);
            }
        }
    }

    PropertyAnimation {
        id: showAnimation
        target: sideBar
        property: "x"
        to: 0
        easing {
            type: Easing.InQuad
        }
        duration: 250
        onStarted: {
            sideBar.visible = true;
        }
    }

    PropertyAnimation {
        id: hideAnimation
        target: sideBar
        property: "x"
        to: -sideBar.width
        duration: 250
        easing {
            type: Easing.OutQuad
        }

        onStopped: {
            sideBar.visible = false;
        }
    }

    function show() {
        showAnimation.start();
    }

    function hide() {
        hideAnimation.start();
    }

    function toggle() {
        if (visible) {
            titleBar.toggleButton.source = "qrc:/Resources/hamburger_icon.png"
            hide();
        } else {
            show();
            if (Qt.platform.os === "android")
                titleBar.toggleButton.source = "qrc:/Resources/back.png"
        }
    }
}
